@@ -113,7 +113,8 @@ def bot_send(section, bot_message, bot_photo="" ):
 
     ### filename = ""
     if (type(bot_photo)==np.ndarray):
-        filename = os.path.expanduser( f"/tmp/flashcam_%Y%m%d_%H%M%S.jpg" )
+        filename = os.path.expanduser( f"/tmp/flashcam_{dt.datetime.now().strftime('%Y%m%d_%H%M%S')}.jpg" )
+        print(f"i... (tele:) writing ndarr image {filename}")
         cv2.imwrite(filename, bot_photo)
         bot_photo = filename
 
